'''
/* 
 * Copyright (C) 2010-2011 Anish Patil <apatil@redhat.com>
 * Copyright (C) 2010-2011 Red Hat, Inc.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
'''
from gi.repository import Gtk
from gi.repository import Gdk
from gi.repository import Pango
from translitarate import Translitarate,SetItems
from os import path

class TranslateUI:
    def __init__(self):
        filename = path.join(path.dirname(__file__),"transliteration.glade")
        self.builder = Gtk.Builder()
        self.builder.add_from_file(filename)
        event_handler = EventHander('English','Marathi')
        self.builder.connect_signals(event_handler)
        window = self.builder.get_object("window1")
        window.set_title('GNOME-Transliteration')
        window.show()
        source_lang = self.builder.get_object("source_lang")
        source_lang.set_active(0)
        source_lang.connect('changed', event_handler.changed_src_cb)
        dest_lang = self.builder.get_object("dest_lang")
        dest_lang.set_active(0)
        dest_lang.connect('changed', event_handler.changed_dest_cb)
        trans_method = self.builder.get_object("trans_method")
        trans_method.connect('changed', event_handler.changed_trans_method_cb)
        self.setitem = SetItems(trans_method)
        model = dest_lang.get_model()
        index = dest_lang.get_active()
        if index > -1:
            key_map = self.setitem.set_keymaps(model[index][0])
            event_handler.langvar_obj.set_key_map(key_map)
        # Text View
        textview = self.builder.get_object("textview1")
        textbuffer = textview.get_buffer()
        textbuffer.connect('changed', event_handler.changed_textview)
        textview2 = self.builder.get_object("textview2")
        self.textbuffer2 = textview2.get_buffer()
        quit_menu = self.builder.get_object("imagemenuitem5")
        quit_menu.connect('activate', event_handler.onDeleteWindow)
        about_menu = self.builder.get_object("imagemenuitem10")
        about_menu.connect('activate', event_handler.about_menu,self.builder)

    def get_textbuff_object(self):
        return self.textbuffer2

class LangVariables:
    def __init__(self,src,dest):
        self._source_lang = src
        self._dest_lang = dest
        self._tras_buff = None
        self._key_map = None

    def set_dest_lang(self,lang):
        self._dest_lang = lang

    def set_src_lang(self,lang):
        self._source_lang = lang

    def set_tras_buf(self,trans_buf):
        self._tras_buff = trans_buf

    def clear_tras_buf(self):
        self._tras_buff = None

    def set_key_map(self,key_map):
        self._key_map = key_map

class EventHander:
    def __init__(self,src_lang,dest_lang):
        self.langvar_obj = LangVariables(src_lang,dest_lang)

    def onDeleteWindow(self, *args):
        Gtk.main_quit()

    def changed_dest_cb(self,widget):
        model = widget.get_model()
        index = widget.get_active()
        if index > -1:
            #print model[index][0], 'selected'
            self.langvar_obj.set_dest_lang(model[index][0])
            key_map = Trans_Ui.setitem.set_keymaps(model[index][0])
            self.langvar_obj.set_key_map(key_map)

    def changed_src_cb(self,widget):
        model = widget.get_model()
        index = widget.get_active()
        if index > -1:
            #print model[index][0], 'selected'
            self.langvar_obj.set_src_lang(model[index][0])

    def changed_trans_method_cb(self,widget):
        model = widget.get_model()
        index = widget.get_active()
        if index > -1:
            self.langvar_obj.set_key_map(model[index][0])

    def changed_textview(self,buff):
        startiter, enditer = buff.get_bounds()
        #print buff.get_text(startiter,enditer,True)
        self.langvar_obj.clear_tras_buf()
        self.langvar_obj.set_tras_buf(buff.get_text(startiter,enditer,True))
        Transobj = Translitarate(self.langvar_obj._source_lang,self.langvar_obj._dest_lang,self.langvar_obj._key_map)
        Trans_Ui.get_textbuff_object().set_text(Transobj.trasliterate(self.langvar_obj._tras_buff))

    def about_menu(self,widget,builder):
        abt_dlg = builder.get_object("aboutdialog1")
        abt_dlg.set_program_name('GNOME-Transliteration')
        abt_dlg.run()
        abt_dlg.destroy()


Trans_Ui = TranslateUI()     

if __name__ == '__main__':
    Gtk.main()

