'''
/* 
 * Copyright (C) 2010-2011 Anish Patil <apatil@redhat.com>
 * Copyright (C) 2010-2011 Red Hat, Inc.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
'''

from gi.repository import Translit
from gi.repository import Gtk    

class Translitarate:
    def __init__(self,src,dest,key_map):
        self.src_lang = src
        self.dest_lang = dest
        self.keymap = key_map
        Pref = Tras_Pref()
        self.Trans = Translit.Transliterator.get(Pref.get_trans_lang(self.dest_lang),self.keymap)
        
    def trasliterate(self,buff):
        return self.Trans.transliterate(buff)[0]

class Tras_Pref:
    def __init__(self):
        db = 'm17n'
        icu = "icu"
        self.lang_mapping = { 'Hindi':[db,['hi-itrans','hi-phonetic','hi-vedmata']],
                              'Marathi':[db,['mr-itrans','mr-phonetic']],
                              'Bengali':[db,['bn-itrans','bn-probhat']],
                              'Oriya':[db,['or-itrans','or-phonetic']],
                              'Telgu':[db,['te-itrans','te-pothana']],
                              'Tamil':[db,['ta-itrans','ta-phonetic']],
                              'Gujrathi':[db,['gu-itrans','gu-phonetic']],
                              'Assami':[db,['as-itrans','as-phonetic']],
                              'Kannada':[db,['kn-itrans','kn-kgp']],
                              'Urdu':[db,['ur-phonetic']],
                              'Farsi':[db,['fa-isiri']],
                              'French':[db,['fr-azerty']],
#                              'Dannish':[db,'da-post']
                              'Japanese':[icu,['Latin-Katakana']],
                              'Sinhala':[db,['si-sumihiri','si-singlish','si-wijesekera','si-sumihiri']]
                            }

    def get_trans_lang(self,lang):
        return self.lang_mapping[lang][0]
    
    def get_trans_keymap(self,lang):
        return self.lang_mapping[lang][1]




class SetItems:
    def __init__(self,combox):
        self.combo = combox
        self.category = "Keymap"
        renderer = Gtk.CellRendererText()
        self.combo.pack_start(renderer, True)
        self.combo.add_attribute(renderer, "text", 0)

    def set_keymaps(self,lang):
        key_maps = Tras_Pref().get_trans_keymap(lang)
        model = Gtk.ListStore(str, str, int)
        for i,key_map in enumerate(key_maps):
            model.append([key_map, self.category, i])
        self.combo.set_model(model)
        self.combo.set_active(0)
        return key_maps[0]
